/* Generated by Nim Compiler v1.6.6 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
  #  define nimfr_(proc, file) \
      TFrame FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = 0; nimFrame(&FR_);

  #  define nimfrs_(proc, file, slots, length) \
      struct {TFrame* prev;NCSTRING procname;NI line;NCSTRING filename; NI len; VarSlot s[slots];} FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = length; nimFrame((TFrame*)&FR_);

  #  define nimln_(n, file) \
      FR_.line = n; FR_.filename = file;
  typedef struct tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA;
typedef struct tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg;
typedef struct tySequence__gorEUsBaLXWko3ZkxE9cpKw tySequence__gorEUsBaLXWko3ZkxE9cpKw;
typedef struct tySequence__xxWWYOndkW9adiM61bZkvsg tySequence__xxWWYOndkW9adiM61bZkvsg;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw;
typedef struct tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg;
typedef struct tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g;
typedef struct tySequence__mAI4KvRAgoko9bmrV4QRgaQ tySequence__mAI4KvRAgoko9bmrV4QRgaQ;
typedef struct tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg;
typedef struct tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw;
typedef struct tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig;
typedef struct tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w;
typedef struct tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw;
typedef struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct NimStringDesc NimStringDesc;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw;
typedef struct tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg;
typedef struct tyObject_AssertionDefect__PtYxPmY5X0dorfvxAFbJpQ tyObject_AssertionDefect__PtYxPmY5X0dorfvxAFbJpQ;
typedef struct tyObject_Defect__LbeSGvgPzGzXnW9caIkJqMA tyObject_Defect__LbeSGvgPzGzXnW9caIkJqMA;
typedef struct tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA;
typedef struct tyObject_PyObject_HEAD_EXTRA__AZfyXx4FzGJVoO01VjoS9cw tyObject_PyObject_HEAD_EXTRA__AZfyXx4FzGJVoO01VjoS9cw;
typedef struct tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ;
typedef struct tyObject_PyIterRefcolonObjectType___d9bsBVvwpaMgkPbcqU7T9apw tyObject_PyIterRefcolonObjectType___d9bsBVvwpaMgkPbcqU7T9apw;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg;
typedef struct tyObject_PyModuleDef_Base__rlCDhfYMTJl9bANneNOHAGQ tyObject_PyModuleDef_Base__rlCDhfYMTJl9bANneNOHAGQ;
typedef struct tyObject_PyModuleDef_Slot__vPt0O09cLIJL9aVVlDCzVeRA tyObject_PyModuleDef_Slot__vPt0O09cLIJL9aVVlDCzVeRA;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;
struct tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA {
NCSTRING name;
NCSTRING doc;
tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg* methods;
tySequence__gorEUsBaLXWko3ZkxE9cpKw* types;
tySequence__xxWWYOndkW9adiM61bZkvsg* iterators;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct TGenericSeq {
NI len;
NI reserved;
};
typedef N_CDECL_PTR(void*, tyProc__uQWqJp3WAx8fOY1h9aCwjIg) (void* s, void* a, void* k);
struct tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw {
NCSTRING ml_name;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg ml_meth;
int ml_flags;
NCSTRING ml_doc;
};
typedef N_CDECL_PTR(void*, tyProc__eYT4U6bGFqFBUxk9b15mfOA) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* typ, void* a, void* b);
struct tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg {
NCSTRING name;
NCSTRING doc;
tyProc__eYT4U6bGFqFBUxk9b15mfOA newFunc;
tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg* methods;
tySequence__mAI4KvRAgoko9bmrV4QRgaQ* members;
NI origSize;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* pyType;
};
struct tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg {
NCSTRING name;
int typ;
NI offset;
int flags;
NCSTRING doc;
};
struct tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw {
NCSTRING name;
NCSTRING doc;
tyProc__eYT4U6bGFqFBUxk9b15mfOA newFunc;
};
typedef N_CDECL_PTR(void*, tyProc__SsjMo29bx9bP5kwe2xgM3Scg) (NCSTRING f, ...);
typedef N_CDECL_PTR(void*, tyProc__4wJmT85lsn175X0dPNQv7w) (NI sz);
typedef N_CDECL_PTR(NI, tyProc__YRQqZC12s3573tRGP8MV3g) (void* f);
typedef N_CDECL_PTR(void*, tyProc__oPIasAghCTvCKmvkMeB1xQ) (void* f, NI i);
typedef N_CDECL_PTR(int, tyProc__6slETyyIDJuDOSqkO0hUXA) (void* f, NI i, void* v);
typedef N_CDECL_PTR(int, tyProc__tgpXIILGoVcO9bvYnz9azTVQ) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* f);
typedef N_CDECL_PTR(int, tyProc__T08W9bgbY4bOv2q64h6irpw) (void* m, NCSTRING n, void* o);
typedef N_CDECL_PTR(int, tyProc__fbYpjfe38x3ujjAmVRbI1Q) (void* o);
typedef N_CDECL_PTR(void*, tyProc__YezmFzxOOyM9cb11Eoq1Elg) (void* o, NCSTRING name);
typedef N_CDECL_PTR(void*, tyProc__jvPpjMAkI9bwM1B9apOphnlA) (void* o);
typedef N_CDECL_PTR(void*, tyProc__VQ1ysQk017myXMGb79cPTVw) (void* o, void* k);
typedef N_CDECL_PTR(int, tyProc__7LMjBc4zOHVIsNdulNv7QQ) (void* o, void* k, void* v);
typedef N_CDECL_PTR(int, tyProc__eoRP3F9aLT3mtHj6OkcMSyQ) (void* a, void* b, int op);
typedef N_CDECL_PTR(int, tyProc__8hR9arLDkUs9ag3Pt9bWtjfsg) (void* o, tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w* b, int flags);
typedef N_CDECL_PTR(void, tyProc__vFvpnKOere9bRFN9czzMRlTA) (tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w* b);
typedef N_CDECL_PTR(void*, tyProc__BZ6N5NNdHcK05FTDxQbEWw) (NCSTRING name, void* base, void* dict);
typedef N_CDECL_PTR(NI64, tyProc__mIlNZ9aGaphVJCyIIofK8mg) (void* l);
typedef N_CDECL_PTR(NU64, tyProc__9b5I9aMvpc2qfvARBMMx9blAg) (void* l);
typedef N_CDECL_PTR(double, tyProc__2su9b9chqHYibM7sMkbSaSkA) (void* l);
typedef N_CDECL_PTR(void*, tyProc__RKlUmjvtmKGnc01PbvZaRQ) (long v);
typedef N_CDECL_PTR(int, tyProc__i2exZ7Vtp648U9crOFcq9beQ) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* t1, tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* t2);
struct tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA {
NF re;
NF im;
};
typedef N_CDECL_PTR(tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA, tyProc__N1A5ZvDSgO9c9aRXmVqfn9bAw) (void* op);
typedef N_CDECL_PTR(void*, tyProc__6esIxH9aNBn9aNzK4x86GkYw) (NIM_CHAR* s, NI len);
typedef N_CDECL_PTR(int, tyProc__3FKLKFzOaK7FD6dRLWM6Jw) (void* o, NIM_CHAR** s, NI* len);
typedef N_CDECL_PTR(void*, tyProc__YDKrw1adv61oVQkQhbYyaA) (NCSTRING s);
typedef N_CDECL_PTR(int, tyProc__B2MjSeo07a72ynTQRVYFKw) (void* o, NCSTRING s);
typedef N_CDECL_PTR(NCSTRING, tyProc__p1X2BwWx9a3wsChhykvf29aA) (void* o);
typedef N_CDECL_PTR(void*, tyProc__NzboHqZVJcbdtVGYrOosXQ) (void);
typedef N_CDECL_PTR(int, tyProc__MTei9bsKjha0o1cISO9aLMDg) (void* o, void* k);
typedef N_NIMCALL_PTR(void, tyProc__4SVlZZPmetqBimNsH9cHcOA) (void* o);
typedef N_CDECL_PTR(void, tyProc__ln4kdL5W9bbX4a1xl8nnVXQ) (void);
typedef N_CDECL_PTR(void, tyProc__WYY8i0I79agBofnUcEGCfig) (void* o, NCSTRING s);
typedef N_CDECL_PTR(void, tyProc__32w2ZypAyMWuajvi2Jt79cg) (void* o);
typedef N_CDECL_PTR(void*, tyProc__jcEovQ2rZUNUsYxohT50Ug) (void* p, NCSTRING name, tyProc__32w2ZypAyMWuajvi2Jt79cg destr);
typedef N_CDECL_PTR(void*, tyProc__9b2qzlf3LCKK0JvThQT1atg) (tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* md, void* self, void* module);
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef N_CDECL_PTR(void, tyProc__U0oVFt576Ze44Q9a3eZc5wg) (void** ptype, void** pvalue, void** ptraceback);
struct tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig {
void* module;
tyProc__SsjMo29bx9bP5kwe2xgM3Scg Py_BuildValue;
tyProc__4wJmT85lsn175X0dPNQv7w PyTuple_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyTuple_Size;
tyProc__oPIasAghCTvCKmvkMeB1xQ PyTuple_GetItem;
tyProc__6slETyyIDJuDOSqkO0hUXA PyTuple_SetItem;
void* Py_None;
tyProc__tgpXIILGoVcO9bvYnz9azTVQ PyType_Ready;
tyProc__eYT4U6bGFqFBUxk9b15mfOA PyType_GenericNew;
tyProc__T08W9bgbY4bOv2q64h6irpw PyModule_AddObject;
tyProc__4wJmT85lsn175X0dPNQv7w PyList_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyList_Size;
tyProc__oPIasAghCTvCKmvkMeB1xQ PyList_GetItem;
tyProc__6slETyyIDJuDOSqkO0hUXA PyList_SetItem;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg PyObject_Call;
tyProc__fbYpjfe38x3ujjAmVRbI1Q PyObject_IsTrue;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyObject_GetAttrString;
tyProc__T08W9bgbY4bOv2q64h6irpw PyObject_SetAttrString;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_Dir;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_Str;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_GetIter;
tyProc__VQ1ysQk017myXMGb79cPTVw PyObject_GetItem;
tyProc__7LMjBc4zOHVIsNdulNv7QQ PyObject_SetItem;
tyProc__eoRP3F9aLT3mtHj6OkcMSyQ PyObject_RichCompareBool;
tyProc__8hR9arLDkUs9ag3Pt9bWtjfsg PyObject_GetBuffer;
tyProc__vFvpnKOere9bRFN9czzMRlTA PyBuffer_Release;
tyProc__BZ6N5NNdHcK05FTDxQbEWw PyErr_NewException;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyIter_Next;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyNumber_Long;
tyProc__mIlNZ9aGaphVJCyIIofK8mg PyLong_AsLongLong;
tyProc__9b5I9aMvpc2qfvARBMMx9blAg PyLong_AsUnsignedLongLong;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyFloat_AsDouble;
tyProc__RKlUmjvtmKGnc01PbvZaRQ PyBool_FromLong;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyBool_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyFloat_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyComplex_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyCapsule_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyTuple_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyList_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyBytes_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyUnicode_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PySuper_Type;
tyProc__i2exZ7Vtp648U9crOFcq9beQ PyType_IsSubtype;
tyProc__N1A5ZvDSgO9c9aRXmVqfn9bAw PyComplex_AsCComplex;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyComplex_RealAsDouble;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyComplex_ImagAsDouble;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyUnicode_AsUTF8String;
tyProc__6esIxH9aNBn9aNzK4x86GkYw PyBytes_FromStringAndSize;
tyProc__3FKLKFzOaK7FD6dRLWM6Jw PyBytes_AsStringAndSize;
tyProc__YDKrw1adv61oVQkQhbYyaA PyUnicode_FromString;
tyProc__B2MjSeo07a72ynTQRVYFKw PyUnicode_CompareWithASCIIString;
tyProc__p1X2BwWx9a3wsChhykvf29aA PyString_AsString;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyDict_Type;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyDict_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyDict_Size;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyDict_GetItemString;
tyProc__T08W9bgbY4bOv2q64h6irpw PyDict_SetItemString;
tyProc__VQ1ysQk017myXMGb79cPTVw PyDict_GetItem;
tyProc__7LMjBc4zOHVIsNdulNv7QQ PyDict_SetItem;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyDict_Keys;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyDict_Values;
tyProc__MTei9bsKjha0o1cISO9aLMDg PyDict_Contains;
tyProc__4SVlZZPmetqBimNsH9cHcOA PyDealloc;
tyProc__ln4kdL5W9bbX4a1xl8nnVXQ PyErr_Clear;
tyProc__WYY8i0I79agBofnUcEGCfig PyErr_SetString;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyErr_Occurred;
void* PyExc_TypeError;
tyProc__jcEovQ2rZUNUsYxohT50Ug PyCapsule_New;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyCapsule_GetPointer;
tyProc__YDKrw1adv61oVQkQhbYyaA PyImport_ImportModule;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetBuiltins;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetGlobals;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetLocals;
tyProc__9b2qzlf3LCKK0JvThQT1atg PyCFunction_NewEx;
tyTuple__47w2DboNEPf69aPgubZdd7Q pythonVersion;
tyProc__ln4kdL5W9bbX4a1xl8nnVXQ PyErr_Print;
tyProc__U0oVFt576Ze44Q9a3eZc5wg PyErr_Fetch;
tyProc__U0oVFt576Ze44Q9a3eZc5wg PyErr_NormalizeException;
tyProc__MTei9bsKjha0o1cISO9aLMDg PyErr_GivenExceptionMatches;
void* PyExc_BaseException;
void* PyExc_Exception;
void* PyExc_ArithmeticError;
void* PyExc_FloatingPointError;
void* PyExc_OverflowError;
void* PyExc_ZeroDivisionError;
void* PyExc_AssertionError;
void* PyExc_OSError;
void* PyExc_IOError;
void* PyExc_ValueError;
void* PyExc_EOFError;
void* PyExc_MemoryError;
void* PyExc_IndexError;
void* PyExc_KeyError;
void* NimPyException;
};
typedef void* tyArray__RTLVphsxM9a6IMxFlAllF2Q[1024];
typedef N_STDCALL_PTR(NI, tyProc__uryidYWkntM7ddjZSyxvyQ) (void);
typedef N_STDCALL_PTR(NI32, tyProc__Ph37G33p2ec6K0xFeDk1cQ) (NI hProcess, void** lphModule, NI32 cb, NI32* cbNeeded);
struct RootObj {
TNimType* m_type;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA {
  Exception Sup;
};
struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw {
  tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA Sup;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef N_CDECL_PTR(void*, tyProc__2ujOETN3z9btuXStkbh8Cdg) (NCSTRING name, tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* methods, NCSTRING doc, void* self, int apiver);
struct tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg {
NI ob_refcnt;
void* ob_type;
};
struct tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw {
  tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg Sup;
NI ob_size;
};
typedef N_CDECL_PTR(int, tyProc__rNiGphbUW4RHd2WIj64deg) (void* o, FILE* f, int c);
typedef N_CDECL_PTR(void*, tyProc__k4RBH32nrpDxtGF9acg45zw) (void* a, void* b, int c);
typedef N_CDECL_PTR(void*, tyProc__Cj3MN9a7OA9a51xOtsYjEwBg) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* typ, NI sz);
typedef N_CDECL_PTR(void*, tyProc__3hYcL7bVv9cte9aw9aoXtthhA) (void* c, void** args, size_t nargs, void* kwnames);
struct tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g {
  tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw Sup;
NCSTRING tp_name;
NI tp_basicsize;
NI tp_itemsize;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_dealloc;
tyProc__rNiGphbUW4RHd2WIj64deg tp_print;
tyProc__YezmFzxOOyM9cb11Eoq1Elg tp_getattr;
tyProc__T08W9bgbY4bOv2q64h6irpw tp_setattr;
void* tp_as_async;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_repr;
void* tp_as_number;
void* tp_as_sequence;
void* tp_as_mapping;
void* tp_hash;
void* tp_call;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_str;
tyProc__VQ1ysQk017myXMGb79cPTVw tp_getattro;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_setattro;
void* tp_as_buffer;
unsigned long tp_flags;
NCSTRING tp_doc;
void* tp_traverse;
void* tp_clear;
tyProc__k4RBH32nrpDxtGF9acg45zw tp_richcompare;
NI tp_weaklistoffset;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_iter;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_iternext;
tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* tp_methods;
tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg* tp_members;
void* tp_getset;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* tp_base;
void* tp_dict;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg tp_descr_get;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_descr_set;
NI tp_dictoffset;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_init;
tyProc__Cj3MN9a7OA9a51xOtsYjEwBg tp_alloc;
tyProc__eYT4U6bGFqFBUxk9b15mfOA tp_new;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_free;
void* tp_is_gc;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_bases;
void* tp_mro;
void* tp_cache;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_subclasses;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_weaklist;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_del;
unsigned int tp_version_tag;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_finalize;
tyProc__3hYcL7bVv9cte9aw9aoXtthhA tp_vectorcall;
};
struct tyObject_Defect__LbeSGvgPzGzXnW9caIkJqMA {
  Exception Sup;
};
struct tyObject_AssertionDefect__PtYxPmY5X0dorfvxAFbJpQ {
  tyObject_Defect__LbeSGvgPzGzXnW9caIkJqMA Sup;
};
struct tyObject_PyObject_HEAD_EXTRA__AZfyXx4FzGJVoO01VjoS9cw {
void* ob_next;
void* ob_prev;
};
struct tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA {
TNimType* m_type;
tyObject_PyObject_HEAD_EXTRA__AZfyXx4FzGJVoO01VjoS9cw py_extra_dont_use;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg py_object;
};
struct tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ {
  tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw Sup;
tyObject_PyIterRefcolonObjectType___d9bsBVvwpaMgkPbcqU7T9apw* iRef;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef struct {
N_NIMCALL_PTR(void*, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__peT56IS8cvb9cfUlN5SSjqg;
struct tyObject_PyIterRefcolonObjectType___d9bsBVvwpaMgkPbcqU7T9apw {
tyProc__peT56IS8cvb9cfUlN5SSjqg iter;
};
typedef N_CLOSURE_PTR(void*, TM__LoH0foxqckmmftA2y2Dp9aw_17) (void);
typedef N_CDECL_PTR(void*, tyProc__BEMKLd49c5qNHqmldA6aVaw) (void* m, int apiver);
struct tyObject_PyModuleDef_Base__rlCDhfYMTJl9bANneNOHAGQ {
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg ob_base;
tyProc__NzboHqZVJcbdtVGYrOosXQ m_init;
NI m_index;
void* m_copy;
};
struct tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg {
tyObject_PyModuleDef_Base__rlCDhfYMTJl9bANneNOHAGQ m_base;
NCSTRING m_name;
NCSTRING m_doc;
NI m_size;
tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* m_methods;
tyObject_PyModuleDef_Slot__vPt0O09cLIJL9aVVlDCzVeRA* m_slots;
void* m_traverse;
void* m_clear;
void* m_free;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg {
  TGenericSeq Sup;
  tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw data[SEQ_DECL_SIZE];
};
struct tySequence__mAI4KvRAgoko9bmrV4QRgaQ {
  TGenericSeq Sup;
  tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg data[SEQ_DECL_SIZE];
};
struct tySequence__gorEUsBaLXWko3ZkxE9cpKw {
  TGenericSeq Sup;
  tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg* data[SEQ_DECL_SIZE];
};
struct tySequence__xxWWYOndkW9adiM61bZkvsg {
  TGenericSeq Sup;
  tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};
static N_NIMCALL(void, Marker_tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__mAI4KvRAgoko9bmrV4QRgaQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__gorEUsBaLXWko3ZkxE9cpKw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__xxWWYOndkW9adiM61bZkvsg)(void* p, NI op);
static N_INLINE(void, nimFrame)(TFrame* s);
N_LIB_PRIVATE N_NOINLINE(void, callDepthLimitReached__system_2999)(void);
static N_INLINE(void, popFrame)(void);
N_LIB_PRIVATE N_NIMCALL(void, initCommon__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_293)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m);
static N_INLINE(tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig*, loadPyLibFromThisProcess__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1157)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig*, loadPyLibFromModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_377)(void* m);
static N_INLINE(void*, pythonLibHandleForThisProcess__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1048)(void);
static N_INLINE(void*, findPythonDLL__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1032)(void);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(NIM_BOOL, isPythonLibHandle__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1028)(void* h);
N_LIB_PRIVATE N_NIMCALL(void*, symAddr__pureZdynlib_30)(void* lib, NCSTRING name);
N_LIB_PRIVATE N_NOINLINE(void, raiseIndexError2)(NI i, NI n);
N_LIB_PRIVATE N_NOINLINE(void, raiseOverflow)(void);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5390)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5388)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5339)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__system_5345)(void* usr);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5383)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, initModuleTypes__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_367)(void* p, tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m);
N_LIB_PRIVATE N_NIMCALL(void, initPyNimObjectType__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_380)(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg* td);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
static N_INLINE(void*, pyAlloc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_143)(NI sz);
N_LIB_PRIVATE N_NOCONV(void*, alloc0Impl__system_1745)(NI size);
N_LIB_PRIVATE N_NOINLINE(void, raiseRangeErrorNoArgs)(void);
static N_INLINE(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_403)(void* p);
N_LIB_PRIVATE N_NIMCALL(unsigned long, defaultTPFLAGS__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_204)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___coreZmacros_357)(tyTuple__47w2DboNEPf69aPgubZdd7Q x, tyTuple__47w2DboNEPf69aPgubZdd7Q y);
N_LIB_PRIVATE N_CDECL(void, freeNimObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_152)(void* p);
N_LIB_PRIVATE N_CDECL(void, destructNimObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_155)(void* o);
static N_INLINE(tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA*, toNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_157)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, nimGCunref)(void* p);
N_LIB_PRIVATE N_CDECL(void*, typDescrGet__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_199)(void* a, void* b, void* c);
N_LIB_PRIVATE N_NIMCALL(void*, strToPyObject__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_181)(NimStringDesc* s);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
static N_INLINE(void, incRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_5)(void* p);
static N_INLINE(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_632)(void* p);
N_LIB_PRIVATE N_CDECL(void, destructNimIterator__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_302)(void* o);
static N_INLINE(tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_304)(void* p);
N_LIB_PRIVATE N_CDECL(void*, iterNext__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_330)(void* i);
static N_INLINE(void, updateStackBottom__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_322)(void);
N_LIB_PRIVATE N_NOINLINE(void, nimGC_setStackBottom)(void* theStackBottom);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
static N_INLINE(void, popSafePoint)(void);
static N_INLINE(TFrame*, getFrame)(void);
static N_INLINE(void, setFrame)(TFrame* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(Exception*, getCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void*, pythonException__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_324)(Exception* e);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1727)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15)(void* p);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_CDECL(void*, iterDescrGet__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_194)(void* a, void* b, void* c);
static N_INLINE(void, initPyModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_488)(tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg* p, tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m);
static N_INLINE(tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_506)(void* p);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, pyDictHasKey__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_639)(void* o, NCSTRING k);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_646)(void* o, NCSTRING k);
static N_INLINE(NIM_BOOL, eqeq___system_7814)(NCSTRING x, NCSTRING y);
static N_INLINE(void, pyValueToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_64)(void* v, NimStringDesc** o);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, pyStringToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_45)(void* o, NimStringDesc** output);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void*, getPyArg__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_658)(void* argTuple, void* argDict, NI argIdx, NCSTRING argName);
static N_INLINE(void, pyValueToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_240)(void* v, NI* o);
N_LIB_PRIVATE N_NIMCALL(void, clearAndRaiseConversionError__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_27)(NimStringDesc* toType);
N_LIB_PRIVATE N_NOINLINE(void, raiseRangeErrorI)(NI64 i, NI64 a, NI64 b);
static N_INLINE(void*, nimValueToPy__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZnim95py95marshalling_68)(NI v);
static N_INLINE(void*, nimValueToPy__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZnim95py95marshalling_44)(NI32 v);
N_LIB_PRIVATE TNimType NTIpymoduledesc__gBC8z6Ez5xj3dXoP0ylCRA_;
extern TNimType NTIcstring__S9agCYBinaYZnGWcjTdxclg_;
extern TNimType NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_;
N_LIB_PRIVATE TNimType NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_;
N_LIB_PRIVATE TNimType NTIpytypedesc__BKCcJxogshNojOoN23Qfbg_;
extern TNimType NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_;
extern TNimType NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_;
N_LIB_PRIVATE TNimType NTIseqLpymemberdefT__mAI4KvRAgoko9bmrV4QRgaQ_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_;
N_LIB_PRIVATE TNimType NTIptrpytypedesc__3AXXRUdddopflTxsQPlhmQ_;
N_LIB_PRIVATE TNimType NTIseqLptrpytypedescT__gorEUsBaLXWko3ZkxE9cpKw_;
N_LIB_PRIVATE TNimType NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_;
N_LIB_PRIVATE TNimType NTIseqLpyiteratordescT__xxWWYOndkW9adiM61bZkvsg_;
extern TNimType NTIrefvalueerror__Ie1m0dv1ZHg72IgPRr1cDw_;
extern TNimType NTIvalueerror__yoNlBGx0D2tRizIdhQuENw_;
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_6, "Could not find pythonXX.dll", 27);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_7, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim(144, 9) `not pyLib.isNil` ", 70);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_8, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim(145, 9) `td.pyType.isNil` ", 70);
static NIM_CONST tyTuple__47w2DboNEPf69aPgubZdd7Q TM__LoH0foxqckmmftA2y2Dp9aw_10 = {((NI) 3),
((NI) 10),
((NI) 0)}
;
extern TNimType NTIrefassertiondefect__S8DV6hfcgC9c0IiUsAoR29cQ_;
extern TNimType NTIassertiondefect__PtYxPmY5X0dorfvxAFbJpQ_;
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_11, "Internal pynim error. Free called on Nim object.", 48);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_12, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim(132, 9) `not result.isNil` nimpy internal error converting string", 109);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_13, "nim type", 8);
extern TNimType NTIexception__XEycrCsme5C8CVWAYEcdBQ_;
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_18, "nimpy.", 6);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_20, "Unexpected error encountered: ", 30);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_21, "nim iterator", 12);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_23, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim(82, 9) `not curModuleDef.isNil` ", 76);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_25, "() takes exactly ", 17);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_26, " arguments (", 12);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_27, " given)", 7);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_28, "() missing 1 required positional argument: ", 43);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_32, "() got multiple values for argument ", 36);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_36, "Can\'t convert python obj of type \'$1\' to string", 47);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_37, "() got an unexpected keyword argument ", 38);
STRING_LITERAL(TM__LoH0foxqckmmftA2y2Dp9aw_38, "int", 3);
N_LIB_PRIVATE tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig* pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279;
extern tyProc__uryidYWkntM7ddjZSyxvyQ Dl_1291846229_;
extern tyProc__Ph37G33p2ec6K0xFeDk1cQ Dl_1560282111_;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__system_5292;
extern NU pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278;
extern TSafePoint* excHandler__system_2567;
extern TSafePoint* excHandler__system_2567;
extern TSafePoint* excHandler__system_2567;
extern TSafePoint* excHandler__system_2567;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern Exception* currException__system_2568;
extern Exception* currException__system_2568;
extern Exception* currException__system_2568;
extern Exception* currException__system_2568;
static N_NIMCALL(void, Marker_tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg)(void* p, NI op) {
	tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg* a;
	NI T1_;
	a = (tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__mAI4KvRAgoko9bmrV4QRgaQ)(void* p, NI op) {
	tySequence__mAI4KvRAgoko9bmrV4QRgaQ* a;
	NI T1_;
	a = (tySequence__mAI4KvRAgoko9bmrV4QRgaQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__gorEUsBaLXWko3ZkxE9cpKw)(void* p, NI op) {
	tySequence__gorEUsBaLXWko3ZkxE9cpKw* a;
	NI T1_;
	a = (tySequence__gorEUsBaLXWko3ZkxE9cpKw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__xxWWYOndkW9adiM61bZkvsg)(void* p, NI op) {
	tySequence__xxWWYOndkW9adiM61bZkvsg* a;
	NI T1_;
	a = (tySequence__xxWWYOndkW9adiM61bZkvsg*)p;
	T1_ = (NI)0;
}
static N_INLINE(void, nimFrame)(TFrame* s) {
	{
		if (!(framePtr__system_2566 == ((TFrame*) NIM_NIL))) goto LA3_;
		(*s).calldepth = ((NI16) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		(*s).calldepth = (NI16)((*framePtr__system_2566).calldepth + ((NI16) 1));
	}
	LA1_: ;
	(*s).prev = framePtr__system_2566;
	framePtr__system_2566 = s;
	{
		if (!((*s).calldepth == ((NI16) 2000))) goto LA8_;
		callDepthLimitReached__system_2999();
	}
	LA8_: ;
}
static N_INLINE(void, popFrame)(void) {
	framePtr__system_2566 = (*framePtr__system_2566).prev;
}
N_LIB_PRIVATE N_NIMCALL(void, initPythonModuleDesc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_289)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m, NCSTRING name, NCSTRING doc) {
	nimfr_("initPythonModuleDesc", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(213, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*m).name = name;
	nimln_(214, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*m).doc = doc;
	popFrame();
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NIM_BOOL, isPythonLibHandle__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1028)(void* h) {
	NIM_BOOL result;
	void* s;
	nimfr_("isPythonLibHandle", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (NIM_BOOL)0;
	nimln_(356, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	s = symAddr__pureZdynlib_30(h, "PyModule_AddObject");
	nimln_(357, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = !((s == 0));
	popFrame();
	return result;
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	nimfr_("-%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = (NI)0;
	nimln_(414, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	nimln_(418, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	popFrame();
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	nimfr_("<%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	result = (NIM_BOOL)0;
	nimln_(186, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	nimln_(188, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	popFrame();
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5388)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("rtlAddZCT", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(243, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	addZCT__system_5339((&gch__system_5292.zct), c);
	popFrame();
}
static N_INLINE(void, decRef__system_5390)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("decRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(248, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	nimln_(249, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		nimln_(250, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
		rtlAddZCT__system_5388(c);
	}
	LA4_: ;
	popFrame();
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__system_5345)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	nimfr_("usrToCell", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	nimln_(177, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	popFrame();
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	nimfr_("nimGCunrefNoCycle", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(276, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__system_5345(p);
	decRef__system_5390(T1_);
	popFrame();
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	nimfr_("+%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = (NI)0;
	nimln_(403, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	nimln_(407, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	popFrame();
	return result;
}
static N_INLINE(void, incRef__system_5383)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("incRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(231, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
	popFrame();
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	nimfr_("asgnRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(286, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__system_5345(src);
		incRef__system_5383(T5_);
	}
	LA3_: ;
	nimln_(287, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__system_5345((*dest));
		decRef__system_5390(T10_);
	}
	LA8_: ;
	nimln_(288, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*dest) = src;
	popFrame();
}
static N_INLINE(void*, findPythonDLL__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1032)(void) {
	void* result;
	tyArray__RTLVphsxM9a6IMxFlAllF2Q mods;
	NI32 sz;
	NI pr;
	tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw* T14_;
	NimStringDesc* T15_;
	nimfr_("findPythonDLL", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
{	result = (void*)0;
	nimZeroMem((void*)mods, sizeof(tyArray__RTLVphsxM9a6IMxFlAllF2Q));
	sz = (NI32)0;
	nimln_(362, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	pr = Dl_1291846229_();
	nimln_(363, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		NI32 T3_;
		T3_ = (NI32)0;
		T3_ = Dl_1560282111_(pr, (&mods[(((NI) 0))- 0]), ((NI32) 1024), (&sz));
		if (!!((T3_ == ((NI32) 0)))) goto LA4_;
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			nimln_(128, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
			res = ((NI32) 0);
			{
				nimln_(129, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
				while (1) {
					NI32 TM__LoH0foxqckmmftA2y2Dp9aw_5;
					if (!(res < sz)) goto LA8;
					nimln_(364, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
					i = res;
					{
						NIM_BOOL T11_;
						nimln_(365, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
						if ((NU)(i) > (NU)(1023)){ raiseIndexError2(i, 1023); }
						T11_ = (NIM_BOOL)0;
						T11_ = isPythonLibHandle__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1028(mods[(i)- 0]);
						if (!T11_) goto LA12_;
						nimln_(366, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
						if ((NU)(i) > (NU)(1023)){ raiseIndexError2(i, 1023); }
						result = mods[(i)- 0];
						goto BeforeRet_;
					}
					LA12_: ;
					nimln_(131, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
					if (nimAddInt(res, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_5)) { raiseOverflow(); };
					res = (NI32)(TM__LoH0foxqckmmftA2y2Dp9aw_5);
				} LA8: ;
			}
		}
	}
	LA4_: ;
	T14_ = NIM_NIL;
	T14_ = (tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw*) newObj((&NTIrefvalueerror__Ie1m0dv1ZHg72IgPRr1cDw_), sizeof(tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw));
	(*T14_).Sup.Sup.Sup.m_type = (&NTIvalueerror__yoNlBGx0D2tRizIdhQuENw_);
	(*T14_).Sup.Sup.name = "ValueError";
	T15_ = NIM_NIL;
	T15_ = (*T14_).Sup.Sup.message; (*T14_).Sup.Sup.message = copyStringRC1(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_6));
	if (T15_) nimGCunrefNoCycle(T15_);
	asgnRef((void**) (&(*T14_).Sup.Sup.parent), ((Exception*) NIM_NIL));
	nimln_(367, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	raiseExceptionEx((Exception*)T14_, "ValueError", "findPythonDLL", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim", 367);
	}BeforeRet_: ;
	popFrame();
	return result;
}
static N_INLINE(void*, pythonLibHandleForThisProcess__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1048)(void) {
	void* result;
	nimfr_("pythonLibHandleForThisProcess", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (void*)0;
	nimln_(371, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = findPythonDLL__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1032();
	popFrame();
	return result;
}
static N_INLINE(tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig*, loadPyLibFromThisProcess__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1157)(void) {
	tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig* result;
	void* T1_;
	nimfr_("loadPyLibFromThisProcess", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig*)0;
	nimln_(424, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T1_ = (void*)0;
	T1_ = pythonLibHandleForThisProcess__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1048();
	result = loadPyLibFromModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_377(T1_);
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initCommon__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_293)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m) {
	tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw T5_;
	NI T6_;
	nimfr_("initCommon", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(217, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!(pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279 == 0)) goto LA3_;
		nimln_(218, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279 = loadPyLibFromThisProcess__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_1157();
	}
	LA3_: ;
	nimln_(219, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimZeroMem((void*)(&T5_), sizeof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw));
	unsureAsgnRef((void**) (&(*m).methods), (tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg*) incrSeqV3((TGenericSeq*)((*m).methods), (&NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_)));
	T6_ = (*m).methods->Sup.len++;
	(*m).methods->data[T6_] = T5_;
	popFrame();
}
static N_INLINE(void*, pyAlloc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_143)(NI sz) {
	void* result;
	void* T1_;
	nimfr_("pyAlloc", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(111, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	if ((NU)((NU32)(((NU) (sz))) + (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278)) > (NU)(((NI) 2147483647))){ raiseRangeErrorNoArgs(); }
	T1_ = (void*)0;
	T1_ = alloc0Impl__system_1745(((NI) ((NU)((NU32)(((NU) (sz))) + (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278)))));
	result = ((void*) (T1_));
	popFrame();
	return result;
}
static N_INLINE(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_403)(void* p) {
	tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* result;
	nimfr_("to", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*)0;
	nimln_(154, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) ((NU)((NU32)(((NU) (ptrdiff_t) (p))) + (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278))));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(unsigned long, defaultTPFLAGS__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_204)(void) {
	unsigned long result;
	NI T1_;
	nimfr_("defaultTPFLAGS", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (unsigned long)0;
	nimln_(141, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T1_ = (NI)0;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = lteq___coreZmacros_357(TM__LoH0foxqckmmftA2y2Dp9aw_10, (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).pythonVersion);
		if (!T4_) goto LA5_;
		T1_ = ((NI) 0);
	}
	goto LA2_;
	LA5_: ;
	{
		T1_ = ((NI) 131563);
	}
	LA2_: ;
	result = ((unsigned long) (T1_));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_CDECL(void, freeNimObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_152)(void* p) {
	tyObject_AssertionDefect__PtYxPmY5X0dorfvxAFbJpQ* T1_;
	NimStringDesc* T2_;
	nimfr_("freeNimObj", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T1_ = NIM_NIL;
	T1_ = (tyObject_AssertionDefect__PtYxPmY5X0dorfvxAFbJpQ*) newObj((&NTIrefassertiondefect__S8DV6hfcgC9c0IiUsAoR29cQ_), sizeof(tyObject_AssertionDefect__PtYxPmY5X0dorfvxAFbJpQ));
	(*T1_).Sup.Sup.Sup.m_type = (&NTIassertiondefect__PtYxPmY5X0dorfvxAFbJpQ_);
	(*T1_).Sup.Sup.name = "AssertionDefect";
	T2_ = NIM_NIL;
	T2_ = (*T1_).Sup.Sup.message; (*T1_).Sup.Sup.message = copyStringRC1(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_11));
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*T1_).Sup.Sup.parent), ((Exception*) NIM_NIL));
	nimln_(117, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	raiseExceptionEx((Exception*)T1_, "AssertionDefect", "freeNimObj", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim", 117);
	popFrame();
}
static N_INLINE(tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA*, toNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_157)(void* p) {
	tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA* result;
	nimfr_("toNim", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = NIM_NIL;
	nimln_(114, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = ((tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA*) ((NU)((NU32)(((NU) (ptrdiff_t) (p))) - (NU32)(((NU) 12)))));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_CDECL(void, destructNimObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_155)(void* o) {
	tyObject_PyNimObjectcolonObjectType___EzO9cx6qeJIOpzFHShySXxA* n;
	nimfr_("destructNimObj", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(120, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	n = toNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_157(o);
	nimln_(121, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	if (n) { nimGCunref(n); }
	popFrame();
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, strToPyObject__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_181)(NimStringDesc* s) {
	void* result;
	NCSTRING cs;
	int ln;
	nimfr_("strToPyObject", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(124, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	cs = nimToCStringConv(s);
	nimln_(125, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	ln = ((int) ((s ? s->Sup.len : 0)));
	nimln_(126, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).Py_BuildValue("s#", cs, ln);
	nimln_(127, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!(result == 0)) goto LA3_;
		nimln_(129, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_Clear();
		nimln_(130, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		result = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).Py_BuildValue("y#", cs, ln);
	}
	LA3_: ;
	nimln_(132, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!!(!((result == 0)))) goto LA7_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_12));
	}
	LA7_: ;
	popFrame();
	return result;
}
N_LIB_PRIVATE N_CDECL(void*, typDescrGet__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_199)(void* a, void* b, void* c) {
	void* result;
	nimfr_("typDescrGet", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(138, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = strToPyObject__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_181(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_13));
	popFrame();
	return result;
}
static N_INLINE(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_632)(void* p) {
	tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* result;
	nimfr_("to", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*)0;
	nimln_(154, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = ((tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*) ((NU)((NU32)(((NU) (ptrdiff_t) (p))) + (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278))));
	popFrame();
	return result;
}
static N_INLINE(void, incRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_5)(void* p) {
	tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* T1_;
	NI TM__LoH0foxqckmmftA2y2Dp9aw_14;
	nimfr_("incRef", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
	nimln_(10, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
	T1_ = (tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*)0;
	T1_ = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_632(p);
	if (nimAddInt((*T1_).ob_refcnt, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_14)) { raiseOverflow(); };
	(*T1_).ob_refcnt = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_14);
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(void, initPyNimObjectType__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_380)(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg* td) {
	void* typ;
	tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* ty;
	NI32 TM__LoH0foxqckmmftA2y2Dp9aw_9;
	int T16_;
	nimfr_("initPyNimObjectType", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(144, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!!(!((pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279 == 0)))) goto LA3_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_7));
	}
	LA3_: ;
	nimln_(145, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!!(((*td).pyType == 0))) goto LA7_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_8));
	}
	LA7_: ;
	nimln_(147, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	typ = pyAlloc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_143(((NI) 204));
	nimln_(148, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	ty = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_403(typ);
	nimln_(149, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*td).pyType = ty;
	nimln_(150, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*ty).tp_name = (*td).name;
	nimln_(154, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	if (nimSubInt(((int) ((*td).origSize)), ((int) 4), &TM__LoH0foxqckmmftA2y2Dp9aw_9)) { raiseOverflow(); };
	(*ty).tp_basicsize = ((NI) ((NI32)(TM__LoH0foxqckmmftA2y2Dp9aw_9)));
	nimln_(155, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*ty).tp_flags = defaultTPFLAGS__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_204();
	nimln_(156, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*ty).tp_doc = (*td).doc;
	nimln_(157, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*ty).tp_new = (*td).newFunc;
	nimln_(158, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*ty).tp_free = freeNimObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_152;
	nimln_(159, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*ty).tp_dealloc = destructNimObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_155;
	nimln_(160, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*ty).tp_descr_get = typDescrGet__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_199;
	nimln_(162, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NI T11_;
		tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw T14_;
		NI T15_;
		T11_ = ((*td).methods ? (*td).methods->Sup.len : 0);
		if (!!((T11_ == ((NI) 0)))) goto LA12_;
		nimln_(163, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		nimZeroMem((void*)(&T14_), sizeof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw));
		unsureAsgnRef((void**) (&(*td).methods), (tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg*) incrSeqV3((TGenericSeq*)((*td).methods), (&NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_)));
		T15_ = (*td).methods->Sup.len++;
		(*td).methods->data[T15_] = T14_;
		nimln_(164, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		if (((NI) 0) < 0 || ((NI) 0) >= ((*td).methods ? (*td).methods->Sup.len : 0)){ raiseIndexError2(((NI) 0),((*td).methods ? (*td).methods->Sup.len : 0)-1); }
		(*ty).tp_methods = (&(*td).methods->data[((NI) 0)]);
	}
	LA12_: ;
	nimln_(166, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T16_ = (int)0;
	T16_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyType_Ready(((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (typ)));
	(void)(T16_);
	nimln_(167, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	incRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_5(typ);
	popFrame();
}
static N_INLINE(tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_304)(void* p) {
	tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ* result;
	nimfr_("to", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ*)0;
	nimln_(154, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = ((tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ*) ((NU)((NU32)(((NU) (ptrdiff_t) (p))) + (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278))));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_CDECL(void, destructNimIterator__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_302)(void* o) {
	tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ* n;
	nimfr_("destructNimIterator", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(222, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	n = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_304(o);
	nimln_(223, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	if ((*n).iRef) { nimGCunref((*n).iRef); }
	popFrame();
}
static N_INLINE(void, updateStackBottom__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_322)(void) {
	NI volatile a;
	nimfr_("updateStackBottom", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	a = (NI)0;
	nimln_(231, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimGC_setStackBottom(((void*) (((NU) (ptrdiff_t) ((&a))))));
	popFrame();
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2567;
	excHandler__system_2567 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2567 = (*excHandler__system_2567).prev;
}
static N_INLINE(TFrame*, getFrame)(void) {
	TFrame* result;
	result = (TFrame*)0;
	result = framePtr__system_2566;
	return result;
}
static N_INLINE(void, setFrame)(TFrame* s) {
	framePtr__system_2566 = s;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	nimfr_("nimBorrowCurrentException", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = NIM_NIL;
	nimln_(2417, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = currException__system_2568;
	popFrame();
	return result;
}
static N_INLINE(Exception*, getCurrentException)(void) {
	Exception* result;
	nimfr_("getCurrentException", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = NIM_NIL;
	nimln_(2412, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = currException__system_2568;
	popFrame();
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1727)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1727(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15)(void* p) {
	tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* o;
	NI TM__LoH0foxqckmmftA2y2Dp9aw_19;
	nimfr_("decRef", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
	nimln_(13, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
	o = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_632(p);
	nimln_(14, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
	if (nimSubInt((*o).ob_refcnt, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_19)) { raiseOverflow(); };
	(*o).ob_refcnt = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_19);
	nimln_(15, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
	{
		if (!((*o).ob_refcnt == ((NI) 0))) goto LA3_;
		nimln_(16, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
		(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyDealloc(p);
	}
	LA3_: ;
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(void*, pythonException__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_324)(Exception* e) {
	void* result;
	void* err;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	nimfr_("pythonException", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(238, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T1_ = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = cstrToNimstr((*e).name);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 6);
appendString(T1_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_18));
appendString(T1_, T2_);
	err = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_NewException(nimToCStringConv(T1_), (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).NimPyException, NIM_NIL);
	nimln_(239, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15(err);
	nimln_(240, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T3_ = NIM_NIL;
	T3_ = rawNewString(((*e).message ? (*e).message->Sup.len : 0) + 30);
appendString(T3_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_20));
appendString(T3_, (*e).message);
	(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_SetString(err, nimToCStringConv(T3_));
	popFrame();
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2568), (*currException__system_2568).up);
}
N_LIB_PRIVATE N_CDECL(void*, iterNext__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_330)(void* i) {
	void* result;
	TSafePoint TM__LoH0foxqckmmftA2y2Dp9aw_16;
	tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ* T1_;
	TFrame* _nimCurFrame;
	nimfr_("iterNext", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	_nimCurFrame = getFrame();
	result = (void*)0;
	nimln_(243, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	updateStackBottom__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_322();
	nimln_(244, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	pushSafePoint(&TM__LoH0foxqckmmftA2y2Dp9aw_16);
	TM__LoH0foxqckmmftA2y2Dp9aw_16.status = setjmp(TM__LoH0foxqckmmftA2y2Dp9aw_16.context);
	if (TM__LoH0foxqckmmftA2y2Dp9aw_16.status == 0) {
	nimln_(245, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T1_ = (tyObject_PyIteratorObj__GqRpYj9a7yzFP1C6hQf7QBQ*)0;
	T1_ = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_304(i);
	result = (*(*T1_).iRef).iter.ClP_0((*(*T1_).iRef).iter.ClE_0);
	popSafePoint();
	}
	else {
		popSafePoint();
		setFrame(_nimCurFrame);
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIexception__XEycrCsme5C8CVWAYEcdBQ_))) {
			Exception* e;
			TM__LoH0foxqckmmftA2y2Dp9aw_16.status = 0;
			nimln_(246, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
			e = getCurrentException();
			nimln_(247, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
			result = pythonException__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_324(e);
			popCurrentException();
		}
	}
	if (TM__LoH0foxqckmmftA2y2Dp9aw_16.status != 0) reraiseException();
	popFrame();
	return result;
}
N_LIB_PRIVATE N_CDECL(void*, iterDescrGet__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_194)(void* a, void* b, void* c) {
	void* result;
	nimfr_("iterDescrGet", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(135, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = strToPyObject__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_181(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_21));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initModuleTypes__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_367)(void* p, tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m) {
	tyProc__jvPpjMAkI9bwM1B9apOphnlA selfIter;
	int T19_;
	nimfr_("initModuleTypes", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		nimln_(250, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T2_ = ((*m).types ? (*m).types->Sup.len : 0);
		colontmp_ = T2_;
		nimln_(119, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
		i_2 = ((NI) 0);
		{
			nimln_(120, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
			while (1) {
				void* typ;
				int T5_;
				NI TM__LoH0foxqckmmftA2y2Dp9aw_15;
				if (!(i_2 < colontmp_)) goto LA4;
				nimln_(250, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				i = i_2;
				if (i < 0 || i >= ((*m).types ? (*m).types->Sup.len : 0)){ raiseIndexError2(i,((*m).types ? (*m).types->Sup.len : 0)-1); }
				initPyNimObjectType__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_380((*m).types->data[i]);
				nimln_(252, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				if (i < 0 || i >= ((*m).types ? (*m).types->Sup.len : 0)){ raiseIndexError2(i,((*m).types ? (*m).types->Sup.len : 0)-1); }
				typ = ((void*) ((NU)((NU32)(((NU) (ptrdiff_t) ((*(*m).types->data[i]).pyType))) - (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278))));
				nimln_(250, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				nimln_(253, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				if (i < 0 || i >= ((*m).types ? (*m).types->Sup.len : 0)){ raiseIndexError2(i,((*m).types ? (*m).types->Sup.len : 0)-1); }
				T5_ = (int)0;
				T5_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyModule_AddObject(p, (*(*m).types->data[i]).name, typ);
				(void)(T5_);
				nimln_(122, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
				if (nimAddInt(i_2, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_15)) { raiseOverflow(); };
				i_2 = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_15);
			} LA4: ;
		}
	}
	nimln_(255, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NI T8_;
		void* T11_;
		T8_ = ((*m).iterators ? (*m).iterators->Sup.len : 0);
		if (!!((T8_ == ((NI) 0)))) goto LA9_;
		nimln_(256, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T11_ = (void*)0;
		T11_ = symAddr__pureZdynlib_30((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).module, "PyObject_SelfIter");
		selfIter = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T11_));
	}
	goto LA6_;
	LA9_: ;
	{
		selfIter = NIM_NIL;
	}
	LA6_: ;
	{
		NI i_3;
		NI colontmp__2;
		NI T14_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		nimln_(260, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T14_ = ((*m).iterators ? (*m).iterators->Sup.len : 0);
		colontmp__2 = T14_;
		nimln_(119, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
		i_4 = ((NI) 0);
		{
			nimln_(120, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
			while (1) {
				void* typ_2;
				tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* ty;
				int T17_;
				int T18_;
				NI TM__LoH0foxqckmmftA2y2Dp9aw_22;
				if (!(i_4 < colontmp__2)) goto LA16;
				nimln_(260, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				i_3 = i_4;
				nimln_(261, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				typ_2 = pyAlloc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_143(((NI) 204));
				nimln_(262, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				ty = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_403(typ_2);
				nimln_(263, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				if (i_3 < 0 || i_3 >= ((*m).iterators ? (*m).iterators->Sup.len : 0)){ raiseIndexError2(i_3,((*m).iterators ? (*m).iterators->Sup.len : 0)-1); }
				(*ty).tp_name = (*m).iterators->data[i_3].name;
				nimln_(265, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				(*ty).tp_basicsize = ((NI) 16);
				nimln_(266, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				(*ty).tp_flags = defaultTPFLAGS__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_204();
				nimln_(267, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				if (i_3 < 0 || i_3 >= ((*m).iterators ? (*m).iterators->Sup.len : 0)){ raiseIndexError2(i_3,((*m).iterators ? (*m).iterators->Sup.len : 0)-1); }
				(*ty).tp_doc = (*m).iterators->data[i_3].doc;
				nimln_(268, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				if (i_3 < 0 || i_3 >= ((*m).iterators ? (*m).iterators->Sup.len : 0)){ raiseIndexError2(i_3,((*m).iterators ? (*m).iterators->Sup.len : 0)-1); }
				(*ty).tp_new = (*m).iterators->data[i_3].newFunc;
				nimln_(269, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				(*ty).tp_free = freeNimObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_152;
				nimln_(270, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				(*ty).tp_dealloc = destructNimIterator__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_302;
				nimln_(271, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				(*ty).tp_iternext = iterNext__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_330;
				nimln_(272, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				(*ty).tp_iter = selfIter;
				nimln_(273, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				(*ty).tp_descr_get = iterDescrGet__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_194;
				nimln_(260, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				nimln_(275, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				T17_ = (int)0;
				T17_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyType_Ready(((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (typ_2)));
				(void)(T17_);
				nimln_(260, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				incRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_5(typ_2);
				nimln_(277, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				if (i_3 < 0 || i_3 >= ((*m).iterators ? (*m).iterators->Sup.len : 0)){ raiseIndexError2(i_3,((*m).iterators ? (*m).iterators->Sup.len : 0)-1); }
				T18_ = (int)0;
				T18_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyModule_AddObject(p, (*m).iterators->data[i_3].name, typ_2);
				(void)(T18_);
				nimln_(122, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
				if (nimAddInt(i_4, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_22)) { raiseOverflow(); };
				i_4 = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_22);
			} LA16: ;
		}
	}
	nimln_(280, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).NimPyException = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_NewException("nimpy.NimPyException", NIM_NIL, NIM_NIL);
	nimln_(281, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T19_ = (int)0;
	T19_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyModule_AddObject(p, "NimPyException", (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).NimPyException);
	(void)(T19_);
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(void, initModule2__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_350)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m) {
	tyProc__2ujOETN3z9btuXStkbh8Cdg Py_InitModule4;
	void* T1_;
	nimfr_("initModule2", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(284, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	initCommon__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_293(m);
	Py_InitModule4 = (tyProc__2ujOETN3z9btuXStkbh8Cdg)0;
	nimln_(288, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T1_ = (void*)0;
	T1_ = symAddr__pureZdynlib_30((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).module, "Py_InitModule4");
	Py_InitModule4 = ((tyProc__2ujOETN3z9btuXStkbh8Cdg) (T1_));
	nimln_(289, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		void* T6_;
		if (!(Py_InitModule4 == 0)) goto LA4_;
		nimln_(290, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T6_ = (void*)0;
		T6_ = symAddr__pureZdynlib_30((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).module, "Py_InitModule4_64");
		Py_InitModule4 = ((tyProc__2ujOETN3z9btuXStkbh8Cdg) (T6_));
	}
	LA4_: ;
	nimln_(291, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		void* py;
		if (!!((Py_InitModule4 == 0))) goto LA9_;
		nimln_(292, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		if (((NI) 0) < 0 || ((NI) 0) >= ((*m).methods ? (*m).methods->Sup.len : 0)){ raiseIndexError2(((NI) 0),((*m).methods ? (*m).methods->Sup.len : 0)-1); }
		py = Py_InitModule4((*m).name, (&(*m).methods->data[((NI) 0)]), (*m).doc, NIM_NIL, ((int) 1013));
		nimln_(293, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		initModuleTypes__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_367(py, m);
	}
	LA9_: ;
	popFrame();
}
static N_INLINE(void, initPyModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_488)(tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg* p, tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m) {
	nimfr_("initPyModule", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(296, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*p).m_base.ob_base.ob_refcnt = ((NI) 1);
	nimln_(297, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*p).m_name = (*m).name;
	nimln_(298, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*p).m_doc = (*m).doc;
	nimln_(299, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	(*p).m_size = ((NI) -1);
	nimln_(300, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	if (((NI) 0) < 0 || ((NI) 0) >= ((*m).methods ? (*m).methods->Sup.len : 0)){ raiseIndexError2(((NI) 0),((*m).methods ? (*m).methods->Sup.len : 0)-1); }
	(*p).m_methods = (&(*m).methods->data[((NI) 0)]);
	popFrame();
}
static N_INLINE(tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_506)(void* p) {
	tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg* result;
	nimfr_("to", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg*)0;
	nimln_(154, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = ((tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg*) ((NU)((NU32)(((NU) (ptrdiff_t) (p))) + (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278))));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, initModule3__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_491)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m) {
	void* result;
	tyProc__BEMKLd49c5qNHqmldA6aVaw PyModule_Create2;
	void* T1_;
	nimfr_("initModule3", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(303, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	initCommon__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_293(m);
	PyModule_Create2 = (tyProc__BEMKLd49c5qNHqmldA6aVaw)0;
	nimln_(306, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T1_ = (void*)0;
	T1_ = symAddr__pureZdynlib_30((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).module, "PyModule_Create2");
	PyModule_Create2 = ((tyProc__BEMKLd49c5qNHqmldA6aVaw) (T1_));
	nimln_(308, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		void* T6_;
		if (!(PyModule_Create2 == 0)) goto LA4_;
		nimln_(309, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T6_ = (void*)0;
		T6_ = symAddr__pureZdynlib_30((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).module, "PyModule_Create2TraceRefs");
		PyModule_Create2 = ((tyProc__BEMKLd49c5qNHqmldA6aVaw) (T6_));
	}
	LA4_: ;
	nimln_(311, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		void* pymod;
		tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg* T11_;
		if (!!((PyModule_Create2 == 0))) goto LA9_;
		nimln_(312, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		pymod = pyAlloc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_143(((NI) 52));
		nimln_(313, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T11_ = (tyObject_PyModuleDef__QZDAPlXtpUM7Y9asxNBUBwg*)0;
		T11_ = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_506(pymod);
		initPyModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_488(T11_, m);
		nimln_(314, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		result = PyModule_Create2(pymod, ((int) 3));
		nimln_(315, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		initModuleTypes__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_367(result, m);
	}
	LA9_: ;
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerMethod__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_63)(NCSTRING name, NCSTRING doc, tyProc__uQWqJp3WAx8fOY1h9aCwjIg f) {
	tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw def;
	NI T5_;
	nimfr_("registerMethod", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(82, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!!(!((curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53 == 0)))) goto LA3_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_23));
	}
	LA3_: ;
	nimln_(83, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimZeroMem((void*)(&def), sizeof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw));
	def.ml_name = name;
	def.ml_meth = f;
	def.ml_flags = ((int) 3);
	def.ml_doc = doc;
	nimln_(85, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	unsureAsgnRef((void**) (&(*curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53).methods), (tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg*) incrSeqV3((TGenericSeq*)((*curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53).methods), (&NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_)));
	T5_ = (*curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53).methods->Sup.len++;
	(*curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53).methods->data[T5_] = def;
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, pyDictHasKey__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_639)(void* o, NCSTRING k) {
	NIM_BOOL result;
	void* pk;
	int T1_;
	nimfr_("pyDictHasKey", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (NIM_BOOL)0;
	nimln_(425, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	pk = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyUnicode_FromString(k);
	nimln_(426, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	T1_ = (int)0;
	T1_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyDict_Contains(o, pk);
	result = (T1_ == ((NI32) 1));
	nimln_(427, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15(pk);
	popFrame();
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___system_7814)(NCSTRING x, NCSTRING y) {
	NIM_BOOL result;
	nimfr_("==", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = (NIM_BOOL)0;
	nimln_(2994, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	{
		if (!(((void*) (x)) == ((void*) (y)))) goto LA3_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		nimln_(2995, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
		T6_ = (NIM_BOOL)0;
		T6_ = (x == 0);
		if (T6_) goto LA7_;
		T6_ = (y == 0);
		LA7_: ;
		if (!T6_) goto LA8_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA8_: ;
	{
		int T11_;
		nimln_(2996, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
		T11_ = (int)0;
		T11_ = strcmp(x, y);
		result = (T11_ == ((NI32) 0));
	}
	LA1_: ;
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_646)(void* o, NCSTRING k) {
	NIM_BOOL result;
	nimfr_("==", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (NIM_BOOL)0;
	nimln_(430, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NCSTRING T5_;
		if (!((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyUnicode_CompareWithASCIIString == 0)) goto LA3_;
		nimln_(431, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T5_ = (NCSTRING)0;
		T5_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyString_AsString(o);
		result = eqeq___system_7814(T5_, k);
	}
	goto LA1_;
	LA3_: ;
	{
		int T7_;
		nimln_(433, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T7_ = (int)0;
		T7_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyUnicode_CompareWithASCIIString(o, k);
		result = (T7_ == ((NI32) 0));
	}
	LA1_: ;
	popFrame();
	return result;
}
static N_INLINE(void, pyValueToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_64)(void* v, NimStringDesc** o) {
	nimfr_("pyValueToNim", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
	nimln_(82, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* typ;
		NimStringDesc* errString;
		tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw* T7_;
		tyArray__nHXaesL0DJZHyVS07ARPRA T8_;
		nimln_(2117, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
		nimln_(82, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
		T3_ = (NIM_BOOL)0;
		T3_ = pyStringToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_45(v, o);
		nimln_(2117, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_UNLIKELY(!(T3_));
		if (!T4_) goto LA5_;
		nimln_(84, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
		typ = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) ((*((tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*) (v))).ob_type));
		nimln_(85, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
		errString = copyString(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_36));
		T7_ = NIM_NIL;
		T7_ = (tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw*) newObj((&NTIrefvalueerror__Ie1m0dv1ZHg72IgPRr1cDw_), sizeof(tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw));
		(*T7_).Sup.Sup.Sup.m_type = (&NTIvalueerror__yoNlBGx0D2tRizIdhQuENw_);
		(*T7_).Sup.Sup.name = "ValueError";
		nimln_(86, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
		nimZeroMem((void*)T8_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T8_[0] = cstrToNimstr((*typ).tp_name);
		asgnRef((void**) (&(*T7_).Sup.Sup.message), nsuFormatOpenArray(errString, T8_, 1));
		asgnRef((void**) (&(*T7_).Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T7_, "ValueError", "pyValueToNim", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim", 86);
	}
	LA5_: ;
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, verifyArgs__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_678)(void* argTuple, void* kwargsDict, NI argsLen, NI argsLenReq, NCSTRING* argNames, NI argNamesLen_0, NimStringDesc* funcName) {
	NIM_BOOL result;
	NI nargs;
	NI nkwargs;
	NI sz;
	NI TM__LoH0foxqckmmftA2y2Dp9aw_24;
	NI nkwarg_left;
	TFrame* _nimCurFrame;
	nimfr_("verifyArgs", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
{	_nimCurFrame = getFrame();
	result = (NIM_BOOL)0;
	nimln_(456, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!(argTuple == 0)) goto LA3_;
		nargs = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		nargs = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyTuple_Size(argTuple);
	}
	LA1_: ;
	nimln_(457, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!(kwargsDict == 0)) goto LA8_;
		nkwargs = ((NI) 0);
	}
	goto LA6_;
	LA8_: ;
	{
		nkwargs = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyDict_Size(kwargsDict);
	}
	LA6_: ;
	nimln_(458, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	if (nimAddInt(nargs, nkwargs, &TM__LoH0foxqckmmftA2y2Dp9aw_24)) { raiseOverflow(); };
	sz = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_24);
	nimln_(460, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nkwarg_left = nkwargs;
	nimln_(462, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NIM_BOOL T15_;
		if (!(argsLenReq < argsLen)) goto LA13_;
		nimln_(464, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T15_ = (NIM_BOOL)0;
		T15_ = (argsLenReq <= sz);
		if (!(T15_)) goto LA16_;
		T15_ = (sz <= argsLen);
		LA16_: ;
		result = T15_;
	}
	goto LA11_;
	LA13_: ;
	{
		nimln_(466, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		result = (sz == argsLen);
	}
	LA11_: ;
	nimln_(468, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NimStringDesc* T22_;
		NimStringDesc* T23_;
		NimStringDesc* T24_;
		if (!!(result)) goto LA20_;
		nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		nimln_(469, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		T22_ = NIM_NIL;
		T23_ = NIM_NIL;
		T23_ = dollar___systemZdollars_3(argsLen);
		T24_ = NIM_NIL;
		T24_ = dollar___systemZdollars_3(sz);
		T22_ = rawNewString((funcName ? funcName->Sup.len : 0) + (T23_ ? T23_->Sup.len : 0) + (T24_ ? T24_->Sup.len : 0) + 36);
appendString(T22_, funcName);
appendString(T22_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_25));
appendString(T22_, T23_);
appendString(T22_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_26));
appendString(T22_, T24_);
appendString(T22_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_27));
		nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_SetString((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyExc_TypeError, nimToCStringConv(T22_));
		nimln_(469, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		nimln_(452, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA20_: ;
	{
		NI i;
		NI i_2;
		i = (NI)0;
		nimln_(119, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
		i_2 = nargs;
		{
			nimln_(120, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
			while (1) {
				NI TM__LoH0foxqckmmftA2y2Dp9aw_31;
				if (!(i_2 < argsLen)) goto LA27;
				nimln_(471, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
				i = i_2;
				{
					NIM_BOOL T30_;
					nimln_(472, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
					T30_ = (NIM_BOOL)0;
					T30_ = (i < argsLenReq);
					if (!(T30_)) goto LA31_;
					T30_ = !((nkwargs == ((NI) 0)));
					LA31_: ;
					if (!T30_) goto LA32_;
					nimln_(473, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
					{
						NIM_BOOL T36_;
						NimStringDesc* T39_;
						NimStringDesc* T40_;
						if (i < 0 || i >= argNamesLen_0){ raiseIndexError2(i,argNamesLen_0-1); }
						T36_ = (NIM_BOOL)0;
						T36_ = pyDictHasKey__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_639(kwargsDict, argNames[i]);
						if (!!(T36_)) goto LA37_;
						nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						nimln_(474, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						T39_ = NIM_NIL;
						if (i < 0 || i >= argNamesLen_0){ raiseIndexError2(i,argNamesLen_0-1); }
						T40_ = NIM_NIL;
						T40_ = cstrToNimstr(argNames[i]);
						T39_ = rawNewString((funcName ? funcName->Sup.len : 0) + (T40_ ? T40_->Sup.len : 0) + 43);
appendString(T39_, funcName);
appendString(T39_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_28));
appendString(T39_, T40_);
						nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_SetString((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyExc_TypeError, nimToCStringConv(T39_));
						nimln_(474, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						nimln_(452, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						result = NIM_FALSE;
						goto BeforeRet_;
					}
					goto LA34_;
					LA37_: ;
					{
						NI TM__LoH0foxqckmmftA2y2Dp9aw_29;
						nimln_(476, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						if (nimSubInt(nkwarg_left, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_29)) { raiseOverflow(); };
						nkwarg_left = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_29);
					}
					LA34_: ;
				}
				goto LA28_;
				LA32_: ;
				{
					nimln_(477, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
					if (!!((nkwargs == ((NI) 0)))) goto LA43_;
					nimln_(478, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
					{
						NIM_BOOL T47_;
						NI TM__LoH0foxqckmmftA2y2Dp9aw_30;
						if (i < 0 || i >= argNamesLen_0){ raiseIndexError2(i,argNamesLen_0-1); }
						T47_ = (NIM_BOOL)0;
						T47_ = pyDictHasKey__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_639(kwargsDict, argNames[i]);
						if (!T47_) goto LA48_;
						nimln_(479, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						if (nimSubInt(nkwarg_left, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_30)) { raiseOverflow(); };
						nkwarg_left = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_30);
					}
					LA48_: ;
				}
				goto LA28_;
				LA43_: ;
				LA28_: ;
				nimln_(122, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
				if (nimAddInt(i_2, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_31)) { raiseOverflow(); };
				i_2 = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_31);
			} LA27: ;
		}
	}
	nimln_(482, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!(((NI) 0) < nkwarg_left)) goto LA52_;
		nimln_(484, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		{
			if (!(((NI) 0) < nargs)) goto LA56_;
			{
				NI i_3;
				NI res;
				i_3 = (NI)0;
				nimln_(90, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
				res = ((NI) 0);
				{
					nimln_(91, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
					while (1) {
						NI TM__LoH0foxqckmmftA2y2Dp9aw_33;
						if (!(res <= nargs)) goto LA60;
						nimln_(485, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						i_3 = res;
						{
							NIM_BOOL T63_;
							NimStringDesc* T66_;
							NimStringDesc* T67_;
							nimln_(486, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
							if (i_3 < 0 || i_3 >= argNamesLen_0){ raiseIndexError2(i_3,argNamesLen_0-1); }
							T63_ = (NIM_BOOL)0;
							T63_ = pyDictHasKey__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_639(kwargsDict, argNames[i_3]);
							if (!T63_) goto LA64_;
							nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
							nimln_(487, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
							T66_ = NIM_NIL;
							if (i_3 < 0 || i_3 >= argNamesLen_0){ raiseIndexError2(i_3,argNamesLen_0-1); }
							T67_ = NIM_NIL;
							T67_ = cstrToNimstr(argNames[i_3]);
							T66_ = rawNewString((funcName ? funcName->Sup.len : 0) + (T67_ ? T67_->Sup.len : 0) + 36);
appendString(T66_, funcName);
appendString(T66_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_32));
appendString(T66_, T67_);
							nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
							(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_SetString((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyExc_TypeError, nimToCStringConv(T66_));
							nimln_(487, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
							nimln_(452, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
							result = NIM_FALSE;
							goto BeforeRet_;
						}
						LA64_: ;
						nimln_(93, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators_1.nim");
						if (nimAddInt(res, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_33)) { raiseOverflow(); };
						res = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_33);
					} LA60: ;
				}
			}
		}
		LA56_: ;
		{
			void* k;
			void* it;
			TSafePoint TM__LoH0foxqckmmftA2y2Dp9aw_34;
			k = (void*)0;
			nimln_(157, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
			it = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyObject_GetIter(kwargsDict);
			nimln_(158, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
			pushSafePoint(&TM__LoH0foxqckmmftA2y2Dp9aw_34);
			TM__LoH0foxqckmmftA2y2Dp9aw_34.status = setjmp(TM__LoH0foxqckmmftA2y2Dp9aw_34.context);
			if (TM__LoH0foxqckmmftA2y2Dp9aw_34.status == 0) {
			{
				nimln_(159, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
				while (1) {
					void* i_4;
					NIM_BOOL found;
					nimln_(160, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
					i_4 = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyIter_Next(it);
					nimln_(161, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
					{
						if (!(i_4 == 0)) goto LA73_;
						goto LA69;
					}
					LA73_: ;
					nimln_(490, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
					k = i_4;
					nimln_(491, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
					found = NIM_FALSE;
					{
						NCSTRING* a;
						NI i_5;
						a = (NCSTRING*)0;
						nimln_(8, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators.nim");
						i_5 = ((NI) 0);
						{
							nimln_(9, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators.nim");
							while (1) {
								NI TM__LoH0foxqckmmftA2y2Dp9aw_35;
								if (!(i_5 < argNamesLen_0)) goto LA77;
								nimln_(492, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
								if (i_5 < 0 || i_5 >= argNamesLen_0){ raiseIndexError2(i_5,argNamesLen_0-1); }
								a = (&argNames[i_5]);
								{
									NIM_BOOL T80_;
									nimln_(493, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
									T80_ = (NIM_BOOL)0;
									T80_ = eqeq___OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_646(k, (*a));
									if (!T80_) goto LA81_;
									nimln_(494, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
									found = NIM_TRUE;
									nimln_(495, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
									goto LA75;
								}
								LA81_: ;
								nimln_(11, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/iterators.nim");
								if (nimAddInt(i_5, ((NI) 1), &TM__LoH0foxqckmmftA2y2Dp9aw_35)) { raiseOverflow(); };
								i_5 = (NI)(TM__LoH0foxqckmmftA2y2Dp9aw_35);
							} LA77: ;
						}
					} LA75: ;
					nimln_(490, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
					{
						NIM_BOOL T85_;
						nimln_(2093, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
						T85_ = (NIM_BOOL)0;
						T85_ = NIM_LIKELY(found);
						if (!T85_) goto LA86_;
						nimln_(497, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15(k);
					}
					goto LA83_;
					LA86_: ;
					{
						NimStringDesc* kStr;
						NimStringDesc* T89_;
						kStr = NIM_NIL;
						nimln_(500, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						pyValueToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_64(k, (&kStr));
						nimln_(501, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15(k);
						nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						nimln_(502, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						T89_ = NIM_NIL;
						T89_ = rawNewString((funcName ? funcName->Sup.len : 0) + (kStr ? kStr->Sup.len : 0) + 38);
appendString(T89_, funcName);
appendString(T89_, ((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_37));
appendString(T89_, kStr);
						nimln_(451, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_SetString((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyExc_TypeError, nimToCStringConv(T89_));
						nimln_(502, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						nimln_(452, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
						result = NIM_FALSE;
						popSafePoint();
						nimln_(158, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_utils.nim");
						decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15(it);
						goto BeforeRet_;
					}
					LA83_: ;
				}
			} LA69: ;
			popSafePoint();
			}
			else {
				popSafePoint();
				setFrame(_nimCurFrame);
			}
			{
				decRef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95utils_15(it);
				if (TM__LoH0foxqckmmftA2y2Dp9aw_34.status != 0) nimLeaveFinally();
			}
			if (TM__LoH0foxqckmmftA2y2Dp9aw_34.status != 0) reraiseException();
		}
	}
	LA52_: ;
	}BeforeRet_: ;
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, getPyArg__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_658)(void* argTuple, void* argDict, NI argIdx, NCSTRING argName) {
	void* result;
	nimfr_("getPyArg", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(439, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyTuple_Size(argTuple);
		if (!(argIdx < T3_)) goto LA4_;
		nimln_(440, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		result = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyTuple_GetItem(argTuple, argIdx);
	}
	LA4_: ;
	nimln_(441, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (result == 0);
		if (!(T8_)) goto LA9_;
		T8_ = !((argDict == 0));
		LA9_: ;
		if (!T8_) goto LA10_;
		nimln_(442, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		result = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyDict_GetItemString(argDict, argName);
	}
	LA10_: ;
	popFrame();
	return result;
}
static N_INLINE(void, pyValueToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_240)(void* v, NI* o) {
	NI64 ll;
	nimfr_("pyValueToNim", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
	nimln_(36, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
	ll = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyLong_AsLongLong(v);
	nimln_(37, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
	{
		if (!(ll == IL64(-1))) goto LA3_;
		{
			void* T7_;
			NIM_BOOL T8_;
			nimln_(2117, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
			nimln_(28, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
			T7_ = (void*)0;
			T7_ = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_Occurred();
			nimln_(2117, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
			T8_ = (NIM_BOOL)0;
			T8_ = NIM_UNLIKELY(!((T7_ == 0)));
			if (!T8_) goto LA9_;
			nimln_(29, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
			clearAndRaiseConversionError__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_27(((NimStringDesc*) &TM__LoH0foxqckmmftA2y2Dp9aw_38));
		}
		LA9_: ;
	}
	LA3_: ;
	nimln_(38, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_nim_marshalling.nim");
	if ((ll) < ((NI) (-2147483647 -1)) || (ll) > ((NI) 2147483647)){ raiseRangeErrorI(ll, ((NI) (-2147483647 -1)), ((NI) 2147483647)); }
	(*o) = ((NI) (ll));
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(void, parseArg__fast_89)(void* argTuple, void* kwargsDict, NI argIdx, NCSTRING argName, NI* result) {
	void* arg;
	nimfr_("parseArg", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimln_(445, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	arg = getPyArg__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_658(argTuple, kwargsDict, argIdx, argName);
	nimln_(446, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	{
		if (!!((arg == 0))) goto LA3_;
		nimln_(447, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		pyValueToNim__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95nim95marshalling_240(arg, result);
	}
	LA3_: ;
	popFrame();
}
static N_INLINE(void*, nimValueToPy__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZnim95py95marshalling_44)(NI32 v) {
	void* result;
	nimfr_("nimValueToPy", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/nim_py_marshalling.nim");
	result = (void*)0;
	nimln_(34, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/nim_py_marshalling.nim");
	result = (*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).Py_BuildValue("i", v);
	popFrame();
	return result;
}
static N_INLINE(void*, nimValueToPy__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZnim95py95marshalling_68)(NI v) {
	void* result;
	nimfr_("nimValueToPy", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/nim_py_marshalling.nim");
	result = (void*)0;
	nimln_(46, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/nim_py_marshalling.nim");
	result = nimValueToPy__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZnim95py95marshalling_44(((NI32) (v)));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, nimValueOrVoidToPy__fast_102)(NI v) {
	void* result;
	nimfr_("nimValueOrVoidToPy", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(604, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = nimValueToPy__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZnim95py95marshalling_68(v);
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nimpy_nimpyDatInit000)(void) {
static TNimNode* TM__LoH0foxqckmmftA2y2Dp9aw_2_5[5];
static TNimNode* TM__LoH0foxqckmmftA2y2Dp9aw_3_7[7];
static TNimNode* TM__LoH0foxqckmmftA2y2Dp9aw_4_3[3];
static TNimNode TM__LoH0foxqckmmftA2y2Dp9aw_0[18];
NTIpymoduledesc__gBC8z6Ez5xj3dXoP0ylCRA_.size = sizeof(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA);
NTIpymoduledesc__gBC8z6Ez5xj3dXoP0ylCRA_.align = NIM_ALIGNOF(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA);
NTIpymoduledesc__gBC8z6Ez5xj3dXoP0ylCRA_.kind = 18;
NTIpymoduledesc__gBC8z6Ez5xj3dXoP0ylCRA_.base = 0;
TM__LoH0foxqckmmftA2y2Dp9aw_2_5[0] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[1];
TM__LoH0foxqckmmftA2y2Dp9aw_0[1].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[1].offset = offsetof(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA, name);
TM__LoH0foxqckmmftA2y2Dp9aw_0[1].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[1].name = "name";
TM__LoH0foxqckmmftA2y2Dp9aw_2_5[1] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[2];
TM__LoH0foxqckmmftA2y2Dp9aw_0[2].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[2].offset = offsetof(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA, doc);
TM__LoH0foxqckmmftA2y2Dp9aw_0[2].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[2].name = "doc";
TM__LoH0foxqckmmftA2y2Dp9aw_2_5[2] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[3];
NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_.size = sizeof(tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg*);
NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_.align = NIM_ALIGNOF(tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg*);
NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_.kind = 24;
NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_.base = (&NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_);
NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_.marker = Marker_tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg;
TM__LoH0foxqckmmftA2y2Dp9aw_0[3].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[3].offset = offsetof(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA, methods);
TM__LoH0foxqckmmftA2y2Dp9aw_0[3].typ = (&NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[3].name = "methods";
TM__LoH0foxqckmmftA2y2Dp9aw_2_5[3] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[4];
NTIpytypedesc__BKCcJxogshNojOoN23Qfbg_.size = sizeof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg);
NTIpytypedesc__BKCcJxogshNojOoN23Qfbg_.align = NIM_ALIGNOF(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg);
NTIpytypedesc__BKCcJxogshNojOoN23Qfbg_.kind = 18;
NTIpytypedesc__BKCcJxogshNojOoN23Qfbg_.base = 0;
TM__LoH0foxqckmmftA2y2Dp9aw_3_7[0] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[6];
TM__LoH0foxqckmmftA2y2Dp9aw_0[6].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[6].offset = offsetof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg, name);
TM__LoH0foxqckmmftA2y2Dp9aw_0[6].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[6].name = "name";
TM__LoH0foxqckmmftA2y2Dp9aw_3_7[1] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[7];
TM__LoH0foxqckmmftA2y2Dp9aw_0[7].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[7].offset = offsetof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg, doc);
TM__LoH0foxqckmmftA2y2Dp9aw_0[7].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[7].name = "doc";
TM__LoH0foxqckmmftA2y2Dp9aw_3_7[2] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[8];
TM__LoH0foxqckmmftA2y2Dp9aw_0[8].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[8].offset = offsetof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg, newFunc);
TM__LoH0foxqckmmftA2y2Dp9aw_0[8].typ = (&NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[8].name = "newFunc";
TM__LoH0foxqckmmftA2y2Dp9aw_3_7[3] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[9];
TM__LoH0foxqckmmftA2y2Dp9aw_0[9].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[9].offset = offsetof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg, methods);
TM__LoH0foxqckmmftA2y2Dp9aw_0[9].typ = (&NTIseqLpymethoddefT__E2XyP5e7Jr9aMpJMjdz5Tkg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[9].name = "methods";
TM__LoH0foxqckmmftA2y2Dp9aw_3_7[4] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[10];
NTIseqLpymemberdefT__mAI4KvRAgoko9bmrV4QRgaQ_.size = sizeof(tySequence__mAI4KvRAgoko9bmrV4QRgaQ*);
NTIseqLpymemberdefT__mAI4KvRAgoko9bmrV4QRgaQ_.align = NIM_ALIGNOF(tySequence__mAI4KvRAgoko9bmrV4QRgaQ*);
NTIseqLpymemberdefT__mAI4KvRAgoko9bmrV4QRgaQ_.kind = 24;
NTIseqLpymemberdefT__mAI4KvRAgoko9bmrV4QRgaQ_.base = (&NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_);
NTIseqLpymemberdefT__mAI4KvRAgoko9bmrV4QRgaQ_.marker = Marker_tySequence__mAI4KvRAgoko9bmrV4QRgaQ;
TM__LoH0foxqckmmftA2y2Dp9aw_0[10].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[10].offset = offsetof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg, members);
TM__LoH0foxqckmmftA2y2Dp9aw_0[10].typ = (&NTIseqLpymemberdefT__mAI4KvRAgoko9bmrV4QRgaQ_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[10].name = "members";
TM__LoH0foxqckmmftA2y2Dp9aw_3_7[5] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[11];
TM__LoH0foxqckmmftA2y2Dp9aw_0[11].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[11].offset = offsetof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg, origSize);
TM__LoH0foxqckmmftA2y2Dp9aw_0[11].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[11].name = "origSize";
TM__LoH0foxqckmmftA2y2Dp9aw_3_7[6] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[12];
TM__LoH0foxqckmmftA2y2Dp9aw_0[12].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[12].offset = offsetof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg, pyType);
TM__LoH0foxqckmmftA2y2Dp9aw_0[12].typ = (&NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[12].name = "pyType";
TM__LoH0foxqckmmftA2y2Dp9aw_0[5].len = 7; TM__LoH0foxqckmmftA2y2Dp9aw_0[5].kind = 2; TM__LoH0foxqckmmftA2y2Dp9aw_0[5].sons = &TM__LoH0foxqckmmftA2y2Dp9aw_3_7[0];
NTIpytypedesc__BKCcJxogshNojOoN23Qfbg_.node = &TM__LoH0foxqckmmftA2y2Dp9aw_0[5];
NTIptrpytypedesc__3AXXRUdddopflTxsQPlhmQ_.size = sizeof(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg*);
NTIptrpytypedesc__3AXXRUdddopflTxsQPlhmQ_.align = NIM_ALIGNOF(tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg*);
NTIptrpytypedesc__3AXXRUdddopflTxsQPlhmQ_.kind = 21;
NTIptrpytypedesc__3AXXRUdddopflTxsQPlhmQ_.base = (&NTIpytypedesc__BKCcJxogshNojOoN23Qfbg_);
NTIptrpytypedesc__3AXXRUdddopflTxsQPlhmQ_.flags = 3;
NTIseqLptrpytypedescT__gorEUsBaLXWko3ZkxE9cpKw_.size = sizeof(tySequence__gorEUsBaLXWko3ZkxE9cpKw*);
NTIseqLptrpytypedescT__gorEUsBaLXWko3ZkxE9cpKw_.align = NIM_ALIGNOF(tySequence__gorEUsBaLXWko3ZkxE9cpKw*);
NTIseqLptrpytypedescT__gorEUsBaLXWko3ZkxE9cpKw_.kind = 24;
NTIseqLptrpytypedescT__gorEUsBaLXWko3ZkxE9cpKw_.base = (&NTIptrpytypedesc__3AXXRUdddopflTxsQPlhmQ_);
NTIseqLptrpytypedescT__gorEUsBaLXWko3ZkxE9cpKw_.marker = Marker_tySequence__gorEUsBaLXWko3ZkxE9cpKw;
TM__LoH0foxqckmmftA2y2Dp9aw_0[4].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[4].offset = offsetof(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA, types);
TM__LoH0foxqckmmftA2y2Dp9aw_0[4].typ = (&NTIseqLptrpytypedescT__gorEUsBaLXWko3ZkxE9cpKw_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[4].name = "types";
TM__LoH0foxqckmmftA2y2Dp9aw_2_5[4] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[13];
NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_.size = sizeof(tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw);
NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_.align = NIM_ALIGNOF(tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw);
NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_.kind = 18;
NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_.base = 0;
NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_.flags = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_4_3[0] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[15];
TM__LoH0foxqckmmftA2y2Dp9aw_0[15].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[15].offset = offsetof(tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw, name);
TM__LoH0foxqckmmftA2y2Dp9aw_0[15].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[15].name = "name";
TM__LoH0foxqckmmftA2y2Dp9aw_4_3[1] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[16];
TM__LoH0foxqckmmftA2y2Dp9aw_0[16].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[16].offset = offsetof(tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw, doc);
TM__LoH0foxqckmmftA2y2Dp9aw_0[16].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[16].name = "doc";
TM__LoH0foxqckmmftA2y2Dp9aw_4_3[2] = &TM__LoH0foxqckmmftA2y2Dp9aw_0[17];
TM__LoH0foxqckmmftA2y2Dp9aw_0[17].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[17].offset = offsetof(tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw, newFunc);
TM__LoH0foxqckmmftA2y2Dp9aw_0[17].typ = (&NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[17].name = "newFunc";
TM__LoH0foxqckmmftA2y2Dp9aw_0[14].len = 3; TM__LoH0foxqckmmftA2y2Dp9aw_0[14].kind = 2; TM__LoH0foxqckmmftA2y2Dp9aw_0[14].sons = &TM__LoH0foxqckmmftA2y2Dp9aw_4_3[0];
NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_.node = &TM__LoH0foxqckmmftA2y2Dp9aw_0[14];
NTIseqLpyiteratordescT__xxWWYOndkW9adiM61bZkvsg_.size = sizeof(tySequence__xxWWYOndkW9adiM61bZkvsg*);
NTIseqLpyiteratordescT__xxWWYOndkW9adiM61bZkvsg_.align = NIM_ALIGNOF(tySequence__xxWWYOndkW9adiM61bZkvsg*);
NTIseqLpyiteratordescT__xxWWYOndkW9adiM61bZkvsg_.kind = 24;
NTIseqLpyiteratordescT__xxWWYOndkW9adiM61bZkvsg_.base = (&NTIpyiteratordesc__3Lh9c29bpC2Iomkl9cQO9cGqEw_);
NTIseqLpyiteratordescT__xxWWYOndkW9adiM61bZkvsg_.marker = Marker_tySequence__xxWWYOndkW9adiM61bZkvsg;
TM__LoH0foxqckmmftA2y2Dp9aw_0[13].kind = 1;
TM__LoH0foxqckmmftA2y2Dp9aw_0[13].offset = offsetof(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA, iterators);
TM__LoH0foxqckmmftA2y2Dp9aw_0[13].typ = (&NTIseqLpyiteratordescT__xxWWYOndkW9adiM61bZkvsg_);
TM__LoH0foxqckmmftA2y2Dp9aw_0[13].name = "iterators";
TM__LoH0foxqckmmftA2y2Dp9aw_0[0].len = 5; TM__LoH0foxqckmmftA2y2Dp9aw_0[0].kind = 2; TM__LoH0foxqckmmftA2y2Dp9aw_0[0].sons = &TM__LoH0foxqckmmftA2y2Dp9aw_2_5[0];
NTIpymoduledesc__gBC8z6Ez5xj3dXoP0ylCRA_.node = &TM__LoH0foxqckmmftA2y2Dp9aw_0[0];
}

